function [out]=pnetday(climIn,siteIn,vegIn)
%
% [out]=pnet_day(climIn,siteIn,vegIn)
%

%% Initialize
clear global;

% Vegetation and site constants
global veg;    % Vegetation parameters (input)
global site;   % Site specific parameters (input)
global clim;   % Climatological time series (input)
global share;  % Internal variables shared between functions
global out;    % Calculated variables intended to be returned to the user
global rstep;  % The current timestep of the execution (day or month)

% Assign input structures to those used within the model
veg = vegIn;
site = siteIn;
clim = climIn;

% Initialize variables
initvars;

%% Main run loop
% Loop through all climate records
for rstep=1:length(clim.doy)

  % End-of-year resets
  if rstep ~= 1
    if clim.doy(rstep) < clim.doy(rstep-1)
      share.GDDTot=0;
      share.OldGDDFolEff=0;
    end
  end

  % Call subroutines
  AtmEnviron;
  Phenology(1);
  Photosyn;
  %Waterbal;
  Phenology(2);

  % Collect results
  out.gpp(rstep)=share.CanopyGrossPsn;
  out.vpd(rstep)=share.VPD;
  out.netpsn(rstep)=share.NetPsnMo;
  out.folmass(rstep)=share.FolMass;
  out.waterstress(rstep)=share.DWater;
end
