function Photosyn
%
% Photosynthesis routine for the PnET ecosystem model.
%


global veg site clim share rstep;


PsnTMax = veg.PsnTOpt + (veg.PsnTOpt - veg.PsnTMin);
DTemp = ((PsnTMax - share.Tday) * (share.Tday - veg.PsnTMin)) / (((PsnTMax - veg.PsnTMin) / 2.0)*((PsnTMax - veg.PsnTMin) / 2.0));
if (clim.tmin(rstep) < 6) && (DTemp > 0) && (share.GDDTot >= veg.GDDFolEnd)
  DTemp = DTemp * (1.0 - ((6.0 - clim.tmin(rstep)) / 6.0) * (share.dayspan(rstep) / 30.0));
end
DTemp = max(DTemp, 0);
share.DVPD = 1.0 - veg.DVPD1 * (power(share.VPD,veg.DVPD2));
ten9 = 1000000000.0;

Amax = (veg.AmaxA + veg.AmaxB * veg.FolNCon);

BaseFolResp = veg.BaseFolRespFrac * Amax;
Amax = Amax * veg.AmaxFrac;
GrossAmax = Amax + BaseFolResp;
GrossAmax = (GrossAmax * share.DVPD * DTemp * share.DayLength * 12.0) / ten9;

if GrossAmax < 0
  GrossAmax = 0;
end
share.DayResp = (BaseFolResp * (power(veg.RespQ10,((share.Tday - veg.PsnTOpt) / 10.0))) * share.DayLength * 12.0) / ten9;
share.NightResp = (BaseFolResp * (power(veg.RespQ10,((share.Tnight - veg.PsnTOpt) / 10.0))) * share.NightLength * 12.0) / ten9;

if share.FolMass > 0
  share.CanopyNetPsn = 0;
  share.CanopyGrossPsn = 0;
  share.LAI = 0;
  share.PosCBalMass = share.FolMass;
  
  for ix = 1:50
    i = ix * (share.FolMass / 50.0);
    SLWLayer = veg.SLWmax - (veg.SLWdel * i);
    share.LAI = share.LAI + (share.FolMass / 50.0) / SLWLayer;
    Il = clim.par(rstep) * exp(-veg.k * share.LAI);
    LightEff = (1.0 - exp(-Il * log(2.0) / veg.HalfSat));
    LayerGrossPsnRate = GrossAmax * LightEff;
    LayerGrossPsn = LayerGrossPsnRate * (share.FolMass / 50.0);
    LayerResp = (share.DayResp + share.NightResp) * (share.FolMass / 50.0);
    LayerNetPsn = LayerGrossPsn - LayerResp;
    if (LayerNetPsn < 0) && (share.PosCBalMass == share.FolMass)
      share.PosCBalMass = (ix - 1.0) * (share.FolMass / 50.0);
    end
    share.CanopyNetPsn = share.CanopyNetPsn + LayerNetPsn;
    share.CanopyGrossPsn = share.CanopyGrossPsn + LayerGrossPsn;
  end

  if (DTemp > 0) && (share.GDDTot > veg.GDDFolEnd) && (clim.doy(rstep) < veg.SenescStart)
    share.PosCBalMassTot = share.PosCBalMassTot + (share.PosCBalMass * share.dayspan(rstep));
    share.PosCBalMassIx = share.PosCBalMassIx + share.dayspan(rstep);
  end  

  if share.LightEffMin > LightEff
    share.LightEffMin = LightEff;
  end
  
else
  share.PosCBalMass = 0;
  share.CanopyNetPsn = 0;
  share.CanopyGrossPsn = 0;
  share.LAI = 0;
  share.DayResp = 0;
  share.NightResp = 0;
end